@@ -1,7 +1,9 @@
 package Lemonldap::NG::Manager::_i18n;
 
+# Developer warning : this file must be utf8 encoded
+
 use AutoLoader qw(AUTOLOAD);
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 
 sub import {
     my ($caller_package) = caller;
@@ -119,82 +121,82 @@ sub fr {
     return {
         apacheSessionModule       => "Module Apache::Session",
         applyConf                 => "Appliquer",
-        areYouSure                => "Etes vous sur ?",
-        authParams                => "Param&egrave;tres d'authentification",
+        areYouSure                => "Êtes vous sur ?",
+        authParams                => "Paramètres d'authentification",
         authenticationType        => "Type d'authentification",
-        canNotReadApplyConfFile   => "Configuration non appliqu&eacute;e: impossible de lire le fichier de configuration",
-        changesAppliedLater       => "Les changements seront effectifs d'ici 10 minutes. Utilisez \"apachectl reload\" sur les serveurs concern&eacute;s pour forcer la prise en compte imm&eacute;diate",
+        canNotReadApplyConfFile   => "Configuration non appliquée: impossible de lire le fichier de configuration",
+        changesAppliedLater       => "Les changements seront effectifs d'ici 10 minutes. Utilisez \"apachectl reload\" sur les serveurs concernés pour forcer la prise en compte immédiate",
         checkLogs                 => "Consultez les journaux d'Apache",
-        confSaved                 => "Configuration sauvegard&eacute;e sous le num&eacute;ro",
-        configLoaded              => "Configuration charg&eacute;e",
+        confSaved                 => "Configuration sauvegardée sous le numéro",
+        configLoaded              => "Configuration chargée",
         configuration             => "Configuration",
-        configurationDeleted      => "Configuration &eacute;ffac&eacute;e",
-        configurationNotDeleted   => "Configuration non &eacute;ffac&eacute;e",
-        configurationWasChanged   => "configuration modifi&eacute;e depuis que vous l'avez t&eacute;l&eacute;charg&eacute;e",
+        configurationDeleted      => "Configuration éffacée",
+        configurationNotDeleted   => "Configuration non éffacée",
+        configurationWasChanged   => "configuration modifiée depuis que vous l'avez téléchargée",
         confirmDeleteConf         => "Vous allez effacer cette configuration. Confirmez-vous ?",
         cookieName                => "Nom du cookie",
         containsAnAssignment      => 'contient une affectation ("="). Confusion possible avec "==".',
         deleteConf                => "Effacer",
         deleteNode                => "Supprimer",
-        deleteVirtualHost         => "Supprimer l'h&ocirc;te virtuel",
+        deleteVirtualHost         => "Supprimer l'hôte virtuel",
         domain                    => "Domaine",
         error                     => "Erreur",
-        exportedVars              => "Attributs LDAP &agrave; exporter",
+        exportedVars              => "Attributs LDAP à exporter",
         field                     => "Champ",
-        generalParameters         => "Param&egrave;tres g&eacute;n&eacute;raux",
-        globalStorageOptions      => "Param&egrave;tres du module Apache::Session",
+        generalParameters         => "Paramètres généraux",
+        globalStorageOptions      => "Paramètres du module Apache::Session",
         group                     => "Groupe",
-        header                    => "En-t&ecirc;te",
-        httpHeaders               => "En-t&ecirc;tes HTTP",
+        header                    => "En-tête",
+        httpHeaders               => "En-têtes HTTP",
         invalidLine               => "Ligne invalide",
-        invalidVirtualHostName    => "Nom de d'h&ocirc;te virtuel incorrect",
-        invalidWhatToTrace        => "La donn&eacute;e &agrave; inscrire dans les journaux ne peut contenir qu'un attribut export&eacute; ou une macro",
+        invalidVirtualHostName    => "Nom de d'hôte virtuel incorrect",
+        invalidWhatToTrace        => "La donnée à inscrire dans les journaux ne peut contenir qu'un attribut exporté ou une macro",
         isNotANumber              => "n'est pas un nombre",
         isNotAValidAttributeName  => "n'est pas un nom d'attribut valide",
         isNotAValidCookieName     => "n'est pas un nom de cookie valide",
         isNotAValidDomainName     => "n'est pas un nom de domaine valide",
         isNotAValidGroupName      => "n'est pas un nom de groupe valide",
-        isNotAValidHTTPHeaderName => "n'est pas un nom d'en-t&ecirc;te HTTP valide",
+        isNotAValidHTTPHeaderName => "n'est pas un nom d'en-tête HTTP valide",
         isNotAValidLDAPAttributeName => "n'est pas un nom d'attribut LDAP valide",
         isNotAValidMacroName      => "n'est pas un nom de macro valide",
-        isNotAValidVirtualHostName => "n'est pas un nom d'h&ocirc;te virtuel valide",
-        lastConf                  => "Derni&egrave;re",
+        isNotAValidVirtualHostName => "n'est pas un nom d'hôte virtuel valide",
+        lastConf                  => "Dernière",
         ldapBase                  => "Base de recherche LDAP",
-        ldapParameters            => "Param&egrave;tres LDAP",
+        ldapParameters            => "Paramètres LDAP",
         ldapPort                  => "Port du serveur LDAP",
         ldapServer                => "Serveur LDAP",
-        locationRules             => "R&egrave;gles",
+        locationRules             => "Règles",
         macro                     => "Macro",
         macros                    => "Macros",
         managerDn                 => "Compte de connexion LDAP",
         managerPassword           => "Mot de passe LDAP",
         newGSOpt                  => "Nouvelle option",
         newGroup                  => "Nouveau groupe",
-        newHeader                 => "Nouvel en-t&ecirc;te",
+        newHeader                 => "Nouvel en-tête",
         newMacro                  => "Nouvelle macro",
-        newRule                   => "Nouvelle r&egrave;gle",
+        newRule                   => "Nouvelle règle",
         newVar                    => "Nouvelle variable",
-        newVirtualHost            => "Nouvel h&ocirc;te virtuel",
+        newVirtualHost            => "Nouvel hôte virtuel",
         nextConf                  => "Suivante",
         portal                    => "Portail",
-        prevConf                  => "Pr&eacute;c&eacute;dente",
-        result                    => "R&eacute;sultat",
-        rule                      => "R&egrave;gle",
-        rules                     => "R&egrave;gles",
+        prevConf                  => "Précédente",
+        result                    => "Résultat",
+        rule                      => "Règle",
+        rules                     => "Règles",
         saveConf                  => "Sauvegarder",
-        saveFailure               => "&Eacute;chec de la sauvegarde",
-        securedCookie             => "Cookie s&eacute;curis&eacute; (SSL)",
+        saveFailure               => "Échec de la sauvegarde",
+        securedCookie             => "Cookie sécurisé (SSL)",
         sessionStorage            => "Stockage des sessions",
-        sessionTimeout            => "Dur&eacute;e de vie des sessions",
+        sessionTimeout            => "Durée de vie des sessions",
         syntaxError               => "Erreur de syntaxe",
         unableToSave              => "Votre navigateur ne supporte pas les objets XMLHTTPRequest: sauvegarde impossible.",
         unknownError              => "Erreur inconnue",
-        unknownErrorInVars        => "Erreur inconnue dans les attributs export&eacute;s",
+        unknownErrorInVars        => "Erreur inconnue dans les attributs exportés",
         userGroups                => "Groupes d'utilisateurs",
         value                     => "Valeur",
-        virtualHosts              => "H&ocirc;tes virtuels",
+        virtualHosts              => "Hôtes virtuels",
         waitingResult             => "En attente...",
-        warningConfNotApplied     => "Vous devez recharger les agents pour que la configuration sauvegard&eacute;e soit appliqu&eacute;e",
-        whatToTrace               => "Donn&eacute;e &agrave; inscrire dans les journaux d'Apache",
+        warningConfNotApplied     => "Vous devez recharger les agents pour que la configuration sauvegardée soit appliquée",
+        whatToTrace               => "Donnée à inscrire dans les journaux d'Apache",
     };
 }
